==> xiaoerke-common-1.0.106-sources.jar: com/cxqm/xiaoerke/common/web/CKFAliyunDeleteFilesCommand.java <==
package com.cxqm.xiaoerke.common.web;

/**
 * Created by yanghb on 17/3/9.
 */
//
// Source code recreated from a .class file by IntelliJ IDEA
// (powered by Fernflower decompiler)
//

import com.ckfinder.connector.configuration.IConfiguration;
import com.ckfinder.connector.data.FilePostParam;
import com.ckfinder.connector.data.ResourceType;
import com.ckfinder.connector.errors.ConnectorException;
import com.ckfinder.connector.handlers.command.IPostCommand;
import com.ckfinder.connector.handlers.command.XMLCommand;
import com.ckfinder.connector.utils.AccessControlUtil;
import com.ckfinder.connector.utils.FileUtils;
import com.cxqm.xiaoerke.common.filter.CKFAliyunBukert;
import com.cxqm.xiaoerke.common.utils.OSSObjectTool;
import com.cxqm.xiaoerke.modules.sys.security.SystemAuthorizingRealm;
import com.cxqm.xiaoerke.modules.sys.utils.UserUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.w3c.dom.Element;

import javax.servlet.http.HttpServletRequest;
import java.io.File;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.regex.Pattern;


public class CKFAliyunDeleteFilesCommand extends XMLCommand implements IPostCommand {
	private List<FilePostParam> files;
	private int filesDeleted;
	private boolean addDeleteNode;

	public CKFAliyunDeleteFilesCommand() {
	}

	protected void createXMLChildNodes(int errorNum, Element rootElement) throws ConnectorException {
		if(this.creator.hasErrors()) {
			Element errorsNode = this.creator.getDocument().createElement("Errors");
			this.creator.addErrors(errorsNode);
			rootElement.appendChild(errorsNode);
		}

		if(this.addDeleteNode) {
			this.createDeleteFielsNode(rootElement);
		}

	}

	private void createDeleteFielsNode(Element rootElement) {
		Element element = this.creator.getDocument().createElement("DeleteFiles");
		element.setAttribute("deleted", String.valueOf(this.filesDeleted));
		rootElement.appendChild(element);
	}

	protected int getDataForXml() {
		this.filesDeleted = 0;
		this.addDeleteNode = false;
		Iterator i$ = this.files.iterator();

		while(i$.hasNext()) {
			FilePostParam fileItem = (FilePostParam)i$.next();
			if(!FileUtils.checkFileName(fileItem.getName())) {
				return 109;
			}

			if(this.configuration.getTypes().get(fileItem.getType()) == null) {
				return 109;
			}

			if(fileItem.getFolder() == null || fileItem.getFolder().equals("") || Pattern.compile("(/\\.|\\p{Cntrl}|//|\\\\|[:*?<>\"\\|])").matcher(fileItem.getFolder()).find()) {
				return 109;
			}

			if(FileUtils.checkIfDirIsHidden(fileItem.getFolder(), this.configuration)) {
				return 109;
			}

			if(FileUtils.checkIfFileIsHidden(fileItem.getName(), this.configuration)) {
				return 109;
			}

			if(FileUtils.checkFileExtension(fileItem.getName(), (ResourceType)this.configuration.getTypes().get(fileItem.getType()), this.configuration, false) == 1) {
				return 109;
			}

			if(!AccessControlUtil.getInstance(this.configuration).checkFolderACL(fileItem.getType(), fileItem.getFolder(), this.userRole, 128)) {
				return 103;
			}

			File file = new File(((ResourceType)this.configuration.getTypes().get(fileItem.getType())).getPath() + fileItem.getFolder(), fileItem.getName());

			try {
				this.addDeleteNode = true;

				String buket_key = CKFAliyunBukert.getBuketKey();
				String userId = CKFAliyunBukert.getUserId();

				SystemAuthorizingRealm.Principal principal = (SystemAuthorizingRealm.Principal) UserUtils.getPrincipal();
				Map<String, ResourceType> types = this.configuration.getTypes();
				String typeName = ((ResourceType) types.get(this.type)).getName();
				if (OSSObjectTool.isExists(buket_key == null || buket_key.trim().equals("") ? OSSObjectTool.BUCKET_BACKEND_PIC : buket_key, userId == null || userId.trim().equals("") ? principal.getId() : "/" + userId +"/" + typeName +this.currentFolder+fileItem.getName())){
					OSSObjectTool.delFile(buket_key == null || buket_key.trim().equals("") ? OSSObjectTool.BUCKET_BACKEND_PIC : buket_key, userId == null || userId.trim().equals("") ? principal.getId() : "/" + userId +"/" + typeName +this.currentFolder+fileItem.getName());
				}else{
					this.creator.appendErrorNodeChild(117, fileItem.getName(), fileItem.getFolder(), fileItem.getType());
				}
			} catch (SecurityException var7) {
				if(this.configuration.isDebugMode()) {
					throw var7;
				}

				return 104;
			}
		}

		if(this.creator.hasErrors()) {
			return 302;
		} else {
			return 0;
		}
	}

	public void initParams(HttpServletRequest request, IConfiguration configuration, Object... params) throws ConnectorException {
		super.initParams(request, configuration, new Object[0]);
		this.files = new ArrayList();
		this.getFilesListFromRequest(request);
	}

	private void getFilesListFromRequest(HttpServletRequest request) {
		int i = 0;

		StringBuilder var10000;
		for(String paramName = "files[" + i + "][name]"; request.getParameter(paramName) != null; paramName = var10000.append(i).append("][name]").toString()) {
			FilePostParam file = new FilePostParam();
			file.setName(this.getParameter(request, paramName));
			file.setFolder(this.getParameter(request, "files[" + i + "][folder]"));
			file.setOptions(this.getParameter(request, "files[" + i + "][options]"));
			file.setType(this.getParameter(request, "files[" + i + "][type]"));
			this.files.add(file);
			var10000 = (new StringBuilder()).append("files[");
			++i;
		}

	}
	protected boolean checkIfCurrFolderExists(HttpServletRequest request) throws ConnectorException{
		return true;
	}

}

==> xiaoerke-common-1.1.8-sources.jar: com/cxqm/xiaoerke/common/web/CKFAliyunDeleteFilesCommand.java <==
package com.cxqm.xiaoerke.common.web;

/**
 * Created by yanghb on 17/3/9.
 */
//
// Source code recreated from a .class file by IntelliJ IDEA
// (powered by Fernflower decompiler)
//

import com.ckfinder.connector.configuration.IConfiguration;
import com.ckfinder.connector.data.FilePostParam;
import com.ckfinder.connector.data.ResourceType;
import com.ckfinder.connector.errors.ConnectorException;
import com.ckfinder.connector.handlers.command.IPostCommand;
import com.ckfinder.connector.handlers.command.XMLCommand;
import com.ckfinder.connector.utils.AccessControlUtil;
import com.ckfinder.connector.utils.FileUtils;
import com.cxqm.xiaoerke.common.filter.CKFAliyunBukert;
import com.cxqm.xiaoerke.common.utils.OSSObjectTool;
import com.cxqm.xiaoerke.modules.sys.security.SystemAuthorizingRealm;
import com.cxqm.xiaoerke.modules.sys.utils.UserUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.w3c.dom.Element;

import javax.servlet.http.HttpServletRequest;
import java.io.File;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.regex.Pattern;


public class CKFAliyunDeleteFilesCommand extends XMLCommand implements IPostCommand {
	private List<FilePostParam> files;
	private int filesDeleted;
	private boolean addDeleteNode;

	public CKFAliyunDeleteFilesCommand() {
	}

	protected void createXMLChildNodes(int errorNum, Element rootElement) throws ConnectorException {
		if(this.creator.hasErrors()) {
			Element errorsNode = this.creator.getDocument().createElement("Errors");
			this.creator.addErrors(errorsNode);
			rootElement.appendChild(errorsNode);
		}

		if(this.addDeleteNode) {
			this.createDeleteFielsNode(rootElement);
		}

	}

	private void createDeleteFielsNode(Element rootElement) {
		Element element = this.creator.getDocument().createElement("DeleteFiles");
		element.setAttribute("deleted", String.valueOf(this.filesDeleted));
		rootElement.appendChild(element);
	}

	protected int getDataForXml() {
		this.filesDeleted = 0;
		this.addDeleteNode = false;
		Iterator i$ = this.files.iterator();

		while(i$.hasNext()) {
			FilePostParam fileItem = (FilePostParam)i$.next();
			if(!FileUtils.checkFileName(fileItem.getName())) {
				return 109;
			}

			if(this.configuration.getTypes().get(fileItem.getType()) == null) {
				return 109;
			}

			if(fileItem.getFolder() == null || fileItem.getFolder().equals("") || Pattern.compile("(/\\.|\\p{Cntrl}|//|\\\\|[:*?<>\"\\|])").matcher(fileItem.getFolder()).find()) {
				return 109;
			}

			if(FileUtils.checkIfDirIsHidden(fileItem.getFolder(), this.configuration)) {
				return 109;
			}

			if(FileUtils.checkIfFileIsHidden(fileItem.getName(), this.configuration)) {
				return 109;
			}

			if(FileUtils.checkFileExtension(fileItem.getName(), (ResourceType)this.configuration.getTypes().get(fileItem.getType()), this.configuration, false) == 1) {
				return 109;
			}

			if(!AccessControlUtil.getInstance(this.configuration).checkFolderACL(fileItem.getType(), fileItem.getFolder(), this.userRole, 128)) {
				return 103;
			}

			File file = new File(((ResourceType)this.configuration.getTypes().get(fileItem.getType())).getPath() + fileItem.getFolder(), fileItem.getName());

			try {
				this.addDeleteNode = true;

				String buket_key = CKFAliyunBukert.getBuketKey();
				String userId = CKFAliyunBukert.getUserId();

				SystemAuthorizingRealm.Principal principal = (SystemAuthorizingRealm.Principal) UserUtils.getPrincipal();
				Map<String, ResourceType> types = this.configuration.getTypes();
				String typeName = ((ResourceType) types.get(this.type)).getName();
				if (OSSObjectTool.isExists(buket_key == null || buket_key.trim().equals("") ? OSSObjectTool.BUCKET_BACKEND_PIC : buket_key, (userId == null || userId.trim().equals("") ? principal.getId() : userId) +"/" + typeName +this.currentFolder+fileItem.getName())){
					OSSObjectTool.delFile(buket_key == null || buket_key.trim().equals("") ? OSSObjectTool.BUCKET_BACKEND_PIC : buket_key, (userId == null || userId.trim().equals("") ? principal.getId() : userId) +"/" + typeName +this.currentFolder+fileItem.getName());
				}else{
					this.creator.appendErrorNodeChild(117, fileItem.getName(), fileItem.getFolder(), fileItem.getType());
				}
			} catch (SecurityException var7) {
				if(this.configuration.isDebugMode()) {
					throw var7;
				}

				return 104;
			}
		}

		if(this.creator.hasErrors()) {
			return 302;
		} else {
			return 0;
		}
	}

	public void initParams(HttpServletRequest request, IConfiguration configuration, Object... params) throws ConnectorException {
		super.initParams(request, configuration, new Object[0]);
		this.files = new ArrayList();
		this.getFilesListFromRequest(request);
	}

	private void getFilesListFromRequest(HttpServletRequest request) {
		int i = 0;

		StringBuilder var10000;
		for(String paramName = "files[" + i + "][name]"; request.getParameter(paramName) != null; paramName = var10000.append(i).append("][name]").toString()) {
			FilePostParam file = new FilePostParam();
			file.setName(this.getParameter(request, paramName));
			file.setFolder(this.getParameter(request, "files[" + i + "][folder]"));
			file.setOptions(this.getParameter(request, "files[" + i + "][options]"));
			file.setType(this.getParameter(request, "files[" + i + "][type]"));
			this.files.add(file);
			var10000 = (new StringBuilder()).append("files[");
			++i;
		}

	}
	protected boolean checkIfCurrFolderExists(HttpServletRequest request) throws ConnectorException{
		return true;
	}

}
